# coverage-lcov

`coverage-lcov` is a simple CLI for converting `.coverage` files generated by [Coverage.py](https://github.com/nedbat/coveragepy) to the `LCOV` format.

## Credits

- This tools is based on code from [Coverage.py](https://github.com/nedbat/coveragepy/blob/master/coverage/report.py)
- This tool is forked from [coveragepy-lcov](https://github.com/chaychoong/coveragepy-lcov) by [Chay Choong](https://github.com/chaychoong) to add support for older python versions.

## Installation

Using pip:

```bash
pip install coverage-lcov
```

## Usage

```bash
# If the .coverage file is in your current working directory
coverage-lcov

# Point to a different .coverage file path
coverage-lcov --data_file_path example/.coverage

# Write the output to a different file path
coverage-lcov --output_file_path build/lcov.info

# Use relative paths in the LCOV output
coverage-lcov --relative_path
```

## Options

```text
Usage: coverage-lcov [OPTIONS]

Options:
  --data_file_path TEXT    Path to .coverage file
  --output_file_path TEXT  lcov.info output file path
  --config_file TEXT       Path to .coveragerc file
  --relative_path          Use relative path in LCOV output
  --preview                Preview LCOV output
  --help                   Show this message and exit.
```

## Further reading

- [LCOV format](http://ltp.sourceforge.net/coverage/lcov/geninfo.1.php)
- https://github.com/nedbat/coveragepy/issues/587
- https://github.com/chaychoong/coveragepy-lcov
